@@ -1,9 +1,13 @@
 import numpy
-import read_midifile, pianoteq
-from nuance import *
+import numula.read_midifile, numula.pianoteq
+from numula.nuance import Linear
+from numula.vol_name import *
+
+# example of reading a MIDI file into a Numula Score object
+# and adding nuance to it
 
 def crypto():
-    ns = read_midifile.read_midifile('data/cryptogram.mid', 960, False)
+    ns = numula.read_midifile.read_midifile('data/cryptogram.mid', 960, False)
     ns.vol_adjust_pft(
         [
             Linear(pp, pp, 3/1),
@@ -21,7 +25,7 @@ def crypto():
     ns.roll(14/1+8*3/4+1/4, numpy.linspace(0, .5, 9))
     print(ns)
     ns.write_midi('data/crypto2.mid')
-    pianoteq.play('data/crypto2.mid')
+    numula.pianoteq.play('data/crypto2.mid')
 
 #read_midifile.print_midifile('data/cryptogram.mid')
 
