@@ -9,6 +9,7 @@ import numula.pianoteq
 
 # tags
 # theme_a: the initial RH theme
+
 rh_20_117 = n(' \
     |20 1/16 . (theme_a *2 \
     *2 -c f a- c d- c b- | a- b- a- g f g a- f . * \
@@ -92,6 +93,8 @@ lh_20_117 = n(' \
     1/8 [g- -g-] 3/8 . 10/4 . \
 ').tag('lh')
 
+measure_duration(2/4)
+
 rh_118_211 = n(' \
     |118 (theme_a 1/16 *2 . a c e- g- a- g- f e- f e- d- c d- e- c * \
     . a c e- g- a- g- f *2 1/8 e- 1/16 e- f g- a- g- f * theme_a) \
@@ -121,7 +124,7 @@ rh_118_211 = n(' \
     |182 c e g b- 1/8 +e . 46/4 . \
     |206 1/2 [g3 b- c e] . *3 [g b- c e] * [g3 b- c e] \
     |212 \
-', 1/2).tag('rh')
+').tag('rh')
 
 lh_118_211 = n(' \
     |118 1/4 f2 . . 3/16 . 1/16 +f 1/4 -f . . 3/16 . 1/16 +f \
@@ -156,7 +159,7 @@ lh_118_211 = n(' \
     g e d- b- g e d- b- g e d- b- g e d- b- \
     1/2 g e d- b- 2/2 g 47/16 c 1/16 c \
     |212 \
-', 1/2).tag('lh')
+').tag('lh')
 
 rh_212_299 = n(' \
     |212 1/16 *2 . c4 f a- c d- c b- a- b- a- g f g a- f * \
@@ -171,8 +174,8 @@ rh_212_299 = n(' \
     [-f a] +f [-f b-] +f [-f +c] f [-f +d-] f \
     . --c f a- c -c f a- c -c +g b- c -c e g \
     1/4 [c5 f a- c] 3/16 . 1/16 [f a-] 1/4 [f a-] 3/16 . 1/16 [f a-] \
-    |244 1/2 [f a-] 1/8 [g e] 5/8 . 3/16 . 1/16 [g b-] 1/4 [g b-] \
-    3/16 . 1/16 [g b-] 1/2 [g b-] 1/8 [a- f] 5/8 . 3/16 . 1/16 [+c e-] \
+    |244 1/2 [f a-] 2/8 [g e] 4/8 . 3/16 . 1/16 [g b-] 1/4 [g b-] \
+    3/16 . 1/16 [g b-] 1/2 [g b-] 2/8 [a- f] 4/8 . 3/16 . 1/16 [+c e-] \
     1/4 [c e-] 3/16 . 1/16 [c e-] 5/8 [c e-] \
     1/8 [d- b-] [c a-] [b- g] 1/4 [f a-] \
     3/16 . 1/16 [f a- +f] 1/4 [g -b- g] 3/16 . 1/16 [e g +e] [f -a- f] \
@@ -195,7 +198,7 @@ rh_212_299 = n(' \
     1/4 [-c f a- c] 1/8 . [c f a- c] *4 [-c e +b- c] * \
     1/4 [-c f a- c] 1/8 . [-c a- f c] *4 [+c b- -e c] * \
     |300 \
-', 1/2).tag('rh')
+').tag('rh')
 
 lh_212_299 = n(' \
     |212 1/4 [f3 -f] . . . [f +f] 3/16 . 1/16 [c6 a-] 1/4 [c a-] 1/8 [a- f] . \
@@ -235,7 +238,7 @@ lh_212_299 = n(' \
     d- c b- a- g a- b- a- g f e d c b- a- g \
     |296 *2 f g a- b- c d e f g f e d c b- a- g * \
     |300 \
-', 1/2).tag('lh')
+').tag('lh')
 
 # first ending 300-307
 rh_300_307 = n(' \
@@ -243,12 +246,13 @@ rh_300_307 = n(' \
     1/16 [c e- +a c] a4 c e- g- a c e- g- a c e- g- e- c a \
     g- e- c a g- e- c a g- e- c a g- e- c a *4 g- +e- c a * \
     |308 \
-', 1/2).tag('rh')
+').tag('rh')
+
 lh_300_307 = n(' \
     |300 \
     1/16 f3 e d c b- a- g f g a- b- c d e f g 1/8 [g- -g-] . . . 10/4 . \
     |308 \
-', 1/2).tag('lh')
+').tag('lh')
 
 # second ending onward
 rh_300_end = n(' \
@@ -290,12 +294,13 @@ rh_300_end = n(' \
     |339 e f g a- b- a- g f e f g a- b- c d e \
     |341 *4 f -a- c f 5/16 a- 1/16 -c f a- c a- g e * \
     |349 *3 f c f a- c a- g e * *2 +c a- g e * \
-    +c a- f c +a- f c a- +f c a- f +c a- f c \
-    +a- f c a- +f c a- f +c a- f c +a- f c a- \
-    +f c a- f +c a- f c +a- f c a- +f c a- c \
-    1/8 [a- c f] . . . [+f a- c f] . . . [-f c a- f] . . . \
+    |353 +c a- f c +a- f c a- +f c a- f +c a- f c \
+    |355 +a- f c a- +f c a- f +c a- f c +a- f c a- \
+    |377 +f c a- f +c a- f c +a- f c a- +f c a- c \
+    |359 1/8 [a- c f] . . . [+f a- c f] . . . [-f c a- f] . . . \
     |362 \
 ').tag('rh')
+
 lh_300_end = n(' \
     |300 1/4 f3 1/8 . [c f a- c] *4 [-c e g b- c] * \
     |302 1/4 [-c f a- c] 1/8 . [c f a- c] *4 [-c e g b- c] * \
@@ -351,7 +356,7 @@ v0_20 = ' \
 v1_20 = ' \
     |20 *2 [ mm 2/2 mm ] mf 2/2 mf ] f 2/2 f 2/2 mf * \
     |36 *2 \
-        *2 [ mm 2/2 mf 2/2 mm * mm 2/2 mf_ 4/2 mm \
+        *2 [ mm 2/2 mf 2/2 mm * mm 2/2 mf_ 1/2 _mf 3/2 mm \
         * \
     |64 *5 [ mp 1/2 f_ 1/2 mm * \
     |74 mm 2/2 mf mf 1/2 mp 1/2 mf [ mf_ 1/2 mp_ 1/2 mf_ \
@@ -368,6 +373,7 @@ rhv_36 = ' \
     |90 mm 2/2 mp 2/2 mm 2/2 p \
     |96 *2 *3 [ mp 1/4 _mf 1/4 mp * 1/2 mm * \
     |104 4/2 mm \
+    |108 \
 '
 rha_36 = ' \
     |36 *2 *3 mm 1/4 f 1/4 * f 1/4 f 1/4 * \
@@ -376,7 +382,8 @@ rha_36 = ' \
     |58 1/2 mf 1/2 mf_ 3/2 mf_ 1/2 f \
     |64 32/2 \
     |96 mp *2 2/2 3/8 mf 5/8 * \
-    |104 *2 3/8 mf 5/8 * \
+    |104 *2 _mf 3/8 mf 5/8 * \
+    |108 \
 '
 lhv_36 = ' \
     |36 [ mf_ 14/2 mf_ \
@@ -384,6 +391,7 @@ lhv_36 = ' \
     |64 [ p 10/2 p 2/2 f \
     |76 [ mp 20/2 mp \
     |96 *12 [ mf 1/4 mm 1/4 mf * \
+    |108 \
 '
 lha_36 = ' \
     |36 *3 2/2 mf_ 1/2 mp 1/2 * mp 1/2 _mf 1/2 \
@@ -391,6 +399,7 @@ lha_36 = ' \
     |64 1.8 2/2 *5 2.6 2/2 * *2 f 2/2 * \
     |80 f 6/2 *3 mf 2/2 * 4/2 \
     |96 mp 12/2 \
+    |108 \
 '
 def v20_117(ns, t0):
     # overall shape of exposition
@@ -398,14 +407,14 @@ def v20_117(ns, t0):
         |108 _f 4/2 f \
         |112 f 6/2 pp \
         |118 [ \
-    ', 1/2)
+    ')
 
     # swells at 8 measure level
     v1 = vol(v1_20 + ' \
         |108 mm 2/2 mf 2/2 mm \
         |112 6/2 mm \
         |118 [ \
-    ', 1/2)
+    ')
 
     # swells at 1 measure level
     rhv = vol(' \
@@ -413,7 +422,7 @@ def v20_117(ns, t0):
         ' + rhv_36 + ' \
         |108 10/2 mm \
         |118 [ \
-    ', 1/2)
+    ')
 
     rha = accents(' \
         |20 *2 \
@@ -424,7 +433,7 @@ def v20_117(ns, t0):
         |108 *2 3/8 mf 5/8 * \
         |112 *12 mf_ 1/4 * \
         |118 \
-    ', 1/2)
+    ')
         
     lhv = vol(' \
         |20 _mf 16/2 _mf \
@@ -432,7 +441,7 @@ def v20_117(ns, t0):
         |108 *4 [ mf 1/4 mm 1/4 mf * \
         |112 [ mm 6/2 mm \
         |118 [ \
-    ', 1/2)
+    ')
     lha = accents(' \
         |20 *3 ff 2/2 * \
         |26 f 1/4 f 1/4 f 1/4 f 1/4 \
@@ -440,7 +449,7 @@ def v20_117(ns, t0):
         ' + lha_36 + ' \
         |108 10/2 \
         |118 \
-    ', 1/2)
+    ')
     ns.vol_adjust_pft(v0, t0)
     ns.vol_adjust_pft(v1, t0)
     ns.vol_adjust_pft(rhv, t0, lambda n: 'rh' in n.tags)
@@ -479,10 +488,11 @@ tb_20 = f' \
         6/2 60 {dt0}p \
         * \
     |64 {dt0}p{dt2} *6 60 2/2 60 {dt0}p * \
-    |76 {dt1}p *2 60 2/2 60 {dt0}p * \
+    |76 {dt1}p *2 60 2/2 60 {dt1}p * \
     |80 4/2 60 {dt1}p *6 2/2 60 {dt0}p * \
     |96 {dt1}p{dt2} 4/2 60 \
-    |100 {dt0}p{dt2} 8/2 60 \
+    |100 {dt0}p{dt1} 4/2 60 \
+    |104 *2 {dt0}p{dt1} 2/2 60 * \
     |108 \
 '
 
@@ -491,13 +501,13 @@ def t20_117(ns, t0):
         |108 57 2/2 55 2/2 50 \
         |112 4/2 60 2/2 50 \
         |118 \
-    ', 1/2)
+    ')
     ns.tempo_adjust_pft(ta, t0)
     tb = tempo(tb_20 + f' \
-        |108 60 4/2 60 {dt4}p{dt0} \
+        |108 *2 {dt0}p{dt1} 60 2/2 60 * {dt4}p{dt0} \
         |112 6/2 60 {dt0}p \
         |118 \
-    ', 1/2)
+    ')
     ns.tempo_adjust_pft(tb, t0)
 
 rhp_20 = ' \
@@ -523,14 +533,14 @@ def p20_117(ns, t0):
     rh = pedal(rhp_20 + ' \
         |108 10/2 \
         |118 \
-    ', 1/2)
+    ')
     ns.vsustain_pft(rh, t0, lambda n: 'rh' in n.tags)
     ns.insert_pedal(PedalUse(t0+92/2, 4/2))
 
     lh = pedal(lhp_20 + ' \
         |108 10/2 \
         |118 \
-    ', 1/2)
+    ')
     ns.vsustain_pft(lh, t0+30/2, lambda n: 'lh' in n.tags)
 
 def v118_211(ns, t0):
@@ -544,7 +554,7 @@ def v118_211(ns, t0):
         |168 ] mf 8/2 ff *2 [ ff 4/2 fff * \
         |184 [ p 8/2 pp 20/2 pp  \
         |212 [ \
-    ', 1/2)
+    ')
     rh = vol(' \
         |118 *2 mp 1/2 mm 1/2 mp * *3 mp 1/4 mm 1/4 mp * [ mf 1/2 mm \
         |126 *2 [ mp 1/2 _mf 1/2 mp * mp 2/2 mf 2/2 mp \
@@ -555,14 +565,14 @@ def v118_211(ns, t0):
         |176 [ *2 [ mp 4/2 mf * \
         |184 [ mm 28/2 mm \
         |212 [ \
-    ', 1/2)
+    ')
     rha = accents(' \
         |118 16/2 \
         |134 1/2 1/4 f 1/4 f 1/4 f 1/4 1/4 f 1/4 f 4/2 \
         |142 *2 *3 1/8 f 3/8 * 1/2 *3 1/8 f 3/8 * 1/2 * \
         |158 *4 mf 2/2 * 1/2 3/8 mf 1/8 f 44/2 \
         |212 \
-    ', 1/2)
+    ')
     lh = vol(' \
         |118 mf 4/2 mf 1/4 mf *3 [ mp 1/4 mf 1/4 mp * 1/4 mp \
         |126 [ _p 8/2 _p \
@@ -572,7 +582,7 @@ def v118_211(ns, t0):
         |158 [ mm 1/4 mm *2 [ mp 1/4 mf 3/4 mp * mp 1/4 mf 2/4 mp \
         |164 [ mm 48/2 mm \
         |212 [ \
-    ', 1/2)
+    ')
     # attenuate off-beat chords from 138 to 140
     lha = accents(' \
         |118 2.7 2/2 2.0 2/2 1.8 1/2 ff 1/2 ff 2/2 \
@@ -585,7 +595,7 @@ def v118_211(ns, t0):
         |176 mf 4/2 mf 4/2 \
         |184 28/2 \
         |212 \
-    ', 1/2)
+    ')
     ns.vol_adjust_pft(v0, t0)
     ns.vol_adjust_pft(lh, t0, lambda n: 'lh' in n.tags)
     ns.vol_adjust_pft(rh, t0, lambda n: 'rh' in n.tags)
@@ -604,7 +614,7 @@ def t118_211(ns, t0):
         |168 60 16/2 65 \
         |184 55 28/2 48 \
         |212 \
-    ', 1/2)
+    ')
     f2 = tempo(f' \
         |118 {dt2}p *2 p{dt0} 60 2/2 60 * p{dt0} 4/2 60 \
         |126 {dt1}p{dt2} 60 8/2 60 \
@@ -612,12 +622,12 @@ def t118_211(ns, t0):
         |142 *4 {dt0}p{dt1} 4/2 60 * \
         |158 {dt1}p{dt0} 6/2 60 \
         |164 {dt1}p 3/2 60 \
-        |167 3/8 60 {dt1}p{dt1} 1/8 60 p{dt3} 60 8/2 60 \
-        |176 {dt3}p 8/2 60 \
+        |167 3/8 60 {dt2}p{dt2} 1/8 60 p{dt3} 60 8/2 60 \
+        |176 {dt4}p 8/2 60 \
         |184 .5p 16/2 60 \
         |200 {dt2}p 60 12/2 60 \
         |212 \
-    ', 1/2)
+    ')
     ns.tempo_adjust_pft(f1, t0)
     ns.tempo_adjust_pft(f2, t0)
 
@@ -630,14 +640,14 @@ def p118_211(ns, t0):
         |150 1/8 3/8 1/8 3/8 1/8 7/8 5/8 3/8 1/8 7/8 \
         |158 - 54/2 \
         |212 \
-    ', 1/2)
+    ')
     p = pedal(' \
         |118 - 58/2 \
         |176 *2 + 7/4 - 1/4 * \
         |184 *4 + 3/4 - 1/4 * \
         |192 + 13/2 - 1/2 + 6/2 \
         |212 \
-    ', 1/2)
+    ')
     ns.vsustain_pft(lh, t0, lambda n: 'lh' in n.tags)
     ns.pedal_pft(p, t0)
 
@@ -646,37 +656,37 @@ def p118_211(ns, t0):
 def v212_299(ns, t0):
     v0 = vol(v0_20 + ' \
         |108 [ \
-    ', 1/2)
+    ')
 
     v1 = vol(v1_20 + ' \
         |108 [ \
-    ', 1/2)
+    ')
 
     rhv = vol(' \
         |20 *4 p 1/2 mf_ 1/2 p * \
         |28 [ mm 1/2 mf 1/2 mm [ _mf 1/2 mf_ 1/2 _mf [ mf 2/2 _f 2/2 mf \
         ' + rhv_36 + ' \
         |108 [ \
-    ', 1/2)
+    ')
 
     rha = accents(' \
         |20 16/2 \
         ' + rha_36 + ' \
         |108 \
-    ', 1/2)
+    ')
         
     lhv = vol(' \
         |20 mf_ 8/2 mf_ \
         |28 ] *4 mp 1/2 mm 1/2 mp * \
         ' + lhv_36 + ' \
         |108 [ \
-    ', 1/2)
+    ')
     lha = accents(' \
         |20 f 2/2 f 1/2 f 1/4 mp 1/4 f 1/2 f 3/2 \
         |28 8/2 \
         ' + lha_36 + ' \
         |108 \
-    ', 1/2)
+    ')
     ns.vol_adjust_pft(v0, t0)
     ns.vol_adjust_pft(v1, t0)
     ns.vol_adjust_pft(rhv, t0, lambda n: 'rh' in n.tags)
@@ -687,48 +697,48 @@ def v212_299(ns, t0):
 def t212_299(ns, t0):
     ta = tempo(ta_20 + ' \
         |108 \
-    ', 1/2)
+    ')
     ns.tempo_adjust_pft(ta, t0)
     tb = tempo(tb_20 + ' \
         |108 \
-    ', 1/2)
+    ')
     ns.tempo_adjust_pft(tb, t0)
 
 def p212_299(ns, t0):
     rh = pedal(rhp_20 + ' \
         |108 \
-    ', 1/2)
+    ')
     ns.vsustain_pft(rh, t0, lambda n: 'rh' in n.tags)
 
     lh = pedal(lhp_20 + ' \
         |108 \
-    ', 1/2)
+    ')
     ns.vsustain_pft(lh, t0+30/2, lambda n: 'lh' in n.tags)
 
 def v300_1(ns, t0):
     v = vol(' \
         |300 ff 2/2 ff_ 6/2 p \
         |308 [ \
-    ', 1/2)
+    ')
     ns.vol_adjust_pft(v, t0)
     a = accents(f' \
         |300 2/2 mf 1/4 _mf 1/4 *5 _mf 1/4 _mf 1/4 * \
         |308 \
-    ', 1/2)
+    ')
     ns.vol_adjust_pft(a, t0)
     
 def t300_1(ns, t0):
     t = tempo(f' \
         |300 60 2/2 45 {dt4}p{dt2} 60 6/2 50 \
         |308 \
-    ', 1/2)
+    ')
     ns.tempo_adjust_pft(t, t0)
     
 def p300_1(ns, t0):
     p = pedal(' \
         |300 - 2/2 + 4/2 - 2/2 \
         |308 \
-    ', 1/2)
+    ')
     ns.pedal_pft(p, t0)
     
 def v300_end(ns, t0):
@@ -740,10 +750,14 @@ def v300_end(ns, t0):
         |343 [ _f 8/2 f [ f_ 8/2 _ff \
         |359 ] mf 8/2 ff \
         |367 [ ff 4/2 _ff \
-        |371 6/2 ff [ fff_ 3/2 fff_ \
+        |371 6/2 ff [ ffff 3/2 ffff \
         |380 \
-    ', 1/2)
-    ns.vol_adjust_pft(v, t0)
+    ')
+    lhv = vol(' \
+        |300 mm 43/2 mm \
+        |343 ] mp 37/2 mp \
+        |380 \
+    ')
     a8 = 'mf'    # accents on 8th-note chords in 310 onward
     lha = accents(f' \
         |300 *3 1/2 mf 1/2 mf * mf 1/2 mf 1/2 \
@@ -754,17 +768,19 @@ def v300_end(ns, t0):
         |367 *4 mf_ 1/4 mf_ 1/4 * \
         |371 *6 _f 1/4 _f 1/4 * 3/2 \
         |380 \
-    ', 1/2)
-    ns.vol_adjust_pft(lha, t0, lambda n: 'lh' in n.tags)
+    ')
     rha = accents(f' \
         |300 8/2 \
         |308 *2 2/2 *6 {a8} 1/2 * * \
         |324 2/2 *8 {a8} 1/2 * 2/2 *7 {a8} 1/2 * \
         |343 *8 mf 2/2 * \
-        |359 *4 1/4 f 3/4 * \
+        |359 *4 1/4 mf 3/4 * \
         |367 2/2 1/4 mf 1/4 *7 mf_ 1/4 mf_ 1/4 * 3/2 \
         |380 \
-    ', 1/2)
+    ')
+    ns.vol_adjust_pft(v, t0)
+    ns.vol_adjust_pft(lhv, t0, lambda n: 'lh' in n.tags)
+    ns.vol_adjust_pft(lha, t0, lambda n: 'lh' in n.tags)
     ns.vol_adjust_pft(rha, t0, lambda n: 'rh' in n.tags)
     ns.vol_adjust(
         .9,
@@ -778,10 +794,10 @@ def t300_end(ns, t0):
         |324 70 10/2 70 \
         |334 70 9/2 70 \
         |343 70 15/2 70 1/2 65 \
-        |359 70 14/2 75 3/2 65 1/2 60 \
+        |359 70 14/2 75 3/2 70 1/2 68 \
         |377 50 2/2 45 1/2 45\
         |380 \
-    ', 1/2)
+    ')
     ns.tempo_adjust_pft(ta, t0)
     tb = tempo(f' \
         |300 *3 60 2/2 {dt0}p{dt0} * 60 2/2 60 \
@@ -789,20 +805,19 @@ def t300_end(ns, t0):
         |324 p{dt1} 60 9/2 60 {dt1}p 1/2 60 \
         |334 p{dt1} 60 9/2 60 \
         |343 {dt1}p 60 8/2 60 {dt1}p 8/2 60 \
-        |359 {dt1}p 60 18/2 60 \
+        |359 *4 {dt0}p 60 2/2 60 * \
+        |367 *4 {dt0}p 1/2 60 * 6/2 60 \
         |377 {dt2}p 60 2/2 60 p.3 1/2 60\
         |380 \
-    ', 1/2)
+    ')
     ns.tempo_adjust_pft(tb, t0)
     # needed to create gaps
     ns.pause_before_list(
         [t0+8/2, t0+9/2, t0+10/2, t0+16/2, t0+17/2, t0+18/2,
-             t0+24/2, t0+25/2, t0+26/2, t0+34/2, t0+33/2, t0+36/2,
-             t0+77/2
+             t0+24/2, t0+25/2, t0+26/2, t0+34/2, t0+33/2, t0+36/2
         ],
         [dt2,    dt4,    .3,      dt2,     dt4,     .2,
-             dt2,     dt4,     .3,      dt2,     dt4,     .2,
-             dt2
+             dt2,     dt4,     .3,      dt2,     dt4,     .2
         ]
     ) 
     
@@ -811,21 +826,21 @@ def p300_end(ns, t0):
         |300 - 59/2 \
         |359 *4 + 3/4 - 1/4 * \
         |367 *3 + 3/8 - 1/8 * + 1/8 1/8 1/8 1/8 \
-        |371 + 4/2 +2/2 - 3/2 \
+        |371 + 4/2 + 2/2 - 3/2 \
         |380 \
-    ', 1/2)
+    ')
     ns.vsustain_pft(p, t0)
 
 def main():
     do_20 = True
     do_118 = True
-    do_212 = False
-    do_300_1 = False
-    do_118_rep = False
-    do_212_rep = False
-    do_300_2 = False
+    do_212 = True
+    do_300_1 = True
+    do_118_rep = True
+    do_212_rep = True
+    do_300_2 = True
     
-    ns = Score(tempo=144, verbose=True)
+    ns = Score(tempo=144, verbose=False)
     # must make copies first; append_score() changes note times
     lh_118_211_copy = copy.deepcopy(lh_118_211)
     rh_118_211_copy = copy.deepcopy(rh_118_211)
@@ -898,7 +913,7 @@ def main():
         ns.perf_dur_rel(0.6, lambda n: 'theme_a' in n.tags)
         ns.perf_dur_rel(0.2, lambda n: 'stac' in n.tags)
         
-    #ns.t_random_normal(.007, 2)
+    ns.t_random_normal(.005, 2)
     print(ns)
     ns.write_midi('data/op57.midi', verbose=False)
     numula.pianoteq.play('data/op57.midi',
