@@ -1,5 +1,5 @@
 # This file is part of Numula
-# Copyright (C) 2022 David P. Anderson
+# Copyright (C) 2023 David P. Anderson
 #
 # Numula is free software; you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License
@@ -197,10 +197,10 @@ class Score:
     # initialize perf times if not already done
     #
     def perf_init(self):
+        if self.verbose: print('initializing performance times')
         if self.perf_inited:
+            if self.verbose: print('already inited')
             return
-        if self.verbose:
-            print('initializing performance times')
         self.perf_inited = True
         if not self.notes:
             raise Exception('no notes')
@@ -217,6 +217,7 @@ class Score:
             pedal.perf_dur = self.score_to_perf(pedal.dur)
 
     def perf_init_clear(self):
+        if self.verbose: print('perf_init_clear()')
         self.perf_inited = False
         
     def tags_init(self):
@@ -273,6 +274,7 @@ class Score:
         self.tags_inited = False
 
     def init_all(self):
+        if self.verbose: print('init_all()')
         self.time_sort()
         self.perf_init()
         self.tags_init()
